# Script Steps

A script step automatically runs a provided python script before transitioning to the next step.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The name of the step.

### Workflow:
The workflow this step belongs to.

### Script:
The script that will be executed by this step. Should be valid python and implement the function "run" that has exactly one argument called "process_step". To make changes on the attached instance, call `process_step.process.instance`.

### Status:
The status that will be set in the attached instance's status field upon transitioning to this step. Only applicable if attached model is set.

### Code:
A number representation of this step. Must be unique per workflow.

### Permission:
Defines which permission is needed to be able to view this step being executed.

## Filters:
Filters are accessed by clicking on the symbol in the top left corner of the window.

### Associated Transition:
Displays every step that the specified transition is a part of.

## Search Field:
Typing in the search field allows to filter the steps by name.
